summaryrefslogtreecommitdiffstats
path: root/kbugbuster/backend
diff options
context:
space:
mode:
Diffstat (limited to 'kbugbuster/backend')
-rw-r--r--kbugbuster/backend/bugcommand.cpp10
-rw-r--r--kbugbuster/backend/bugserver.cpp13
-rw-r--r--kbugbuster/backend/bugserverconfig.cpp13
-rw-r--r--kbugbuster/backend/kbbprefs.cpp18
-rw-r--r--kbugbuster/backend/mailsender.cpp2
5 files changed, 29 insertions, 27 deletions
diff --git a/kbugbuster/backend/bugcommand.cpp b/kbugbuster/backend/bugcommand.cpp
index 5aa4d522..25e08184 100644
--- a/kbugbuster/backend/bugcommand.cpp
+++ b/kbugbuster/backend/bugcommand.cpp
@@ -67,7 +67,7 @@ TQString BugCommandClose::mailAddress() const
if (m_message.isEmpty()) {
return TQString();
} else {
- return m_bug.number() + "-done@bugs.kde.org";
+ return m_bug.number() + "-done@bugs.trinitydesktop.org";
}
}
@@ -194,15 +194,15 @@ void BugCommandUnmerge::save( KConfig *config )
TQString BugCommandReply::mailAddress() const
{
- return m_bug.number() + "@bugs.kde.org";
+ return m_bug.number() + "@bugs.trinitydesktop.org";
#if 0
switch ( m_recipient ) {
case Normal:
- return m_bug.number() + "@bugs.kde.org";
+ return m_bug.number() + "@bugs.trinitydesktop.org";
case Maintonly:
- return m_bug.number() + "-maintonly@bugs.kde.org";
+ return m_bug.number() + "-maintonly@bugs.trinitydesktop.org";
case Quiet:
- return m_bug.number() + "-quiet@bugs.kde.org";
+ return m_bug.number() + "-quiet@bugs.trinitydesktop.org";
}
return TQString();
#endif
diff --git a/kbugbuster/backend/bugserverconfig.cpp b/kbugbuster/backend/bugserverconfig.cpp
index aca9d5cd..a09e6c29 100644
--- a/kbugbuster/backend/bugserverconfig.cpp
+++ b/kbugbuster/backend/bugserverconfig.cpp
@@ -31,14 +31,14 @@
BugServerConfig::BugServerConfig()
{
- mName = "KDE";
- mBaseUrl = "http://bugs.kde.org";
- mUser = "bugzilla@kde.org";
- mBugzillaVersion = "KDE";
+ mName = "Trinity";
+ mBaseUrl = "http://bugs.trinitydesktop.org";
+ mUser = "bugzilla@trinitydesktop.org";
+ mBugzillaVersion = "TDE";
}
BugServerConfig::BugServerConfig( const TQString &name, const KURL &baseUrl )
- : mName( name ), mBaseUrl( baseUrl ), mBugzillaVersion( "KDE" )
+ : mName( name ), mBaseUrl( baseUrl ), mBugzillaVersion( "TDE" )
{
}
@@ -104,6 +104,7 @@ TQStringList BugServerConfig::bugzillaVersions()
v << "2.14.2";
v << "2.16.2";
v << "2.17.1";
+ v << "TDE";
v << "KDE";
v << "Bugworld";
@@ -120,7 +121,7 @@ void BugServerConfig::readConfig( KConfig *cfg, const TQString &name )
mUser = cfg->readEntry( "User" );
mPassword = cfg->readEntry( "Password" );
- mBugzillaVersion = cfg->readEntry( "BugzillaVersion", "KDE" );
+ mBugzillaVersion = cfg->readEntry( "BugzillaVersion", "TDE" );
mRecentPackages = cfg->readListEntry( "RecentPackages" );
mCurrentPackage = cfg->readEntry( "CurrentPackage" );
diff --git a/kbugbuster/backend/kbbprefs.cpp b/kbugbuster/backend/kbbprefs.cpp
index 7b6dbb7b..f6f3a69c 100644
--- a/kbugbuster/backend/kbbprefs.cpp
+++ b/kbugbuster/backend/kbbprefs.cpp
@@ -134,21 +134,21 @@ void KBBPrefs::usrWriteConfig()
void KBBPrefs::setMessageButtonsDefault()
{
mMessageButtons.clear();
- mMessageButtons.insert(i18n("Bug Fixed in CVS"),"Thank you for your bug report.\n"
+ mMessageButtons.insert(i18n("Bug Fixed in GIT"),"Thank you for your bug report.\n"
"The bug that you reported has been identified and has been fixed in the\n"
- "latest development (CVS) version of KDE. The bug report will be closed.\n");
+ "latest development version of TDE. The bug report will be closed.\n");
mMessageButtons.insert(i18n("Duplicate Report"),"Thank you for your bug report.\n"
"This bug/feature request has already been reported and this report will\n"
"be marked as a duplicate.\n");
mMessageButtons.insert(i18n("Packaging Bug"),"Thank you for your bug report.\n"
"The bug that you reported appears to be a packaging bug, due to a\n"
"problem in the way in which your distribution/vendor has packaged\n"
- "KDE for distribution.\n"
- "The bug report will be closed since it is not a KDE problem.\n"
+ "TDE for distribution.\n"
+ "The bug report will be closed since it is not a TDE problem.\n"
"Please send the bug report to your distribution/vendor instead.\n");
- mMessageButtons.insert(i18n("Feature Implemented in CVS"),"Thank you for your bug report.\n"
+ mMessageButtons.insert(i18n("Feature Implemented in GIT"),"Thank you for your bug report.\n"
"The feature that you requested has been implemented in the latest\n"
- "development (CVS) version of KDE. The feature request will be closed.\n");
+ "development version of TDE. The feature request will be closed.\n");
mMessageButtons.insert(i18n("More Information Required"),"Thank you for your bug report.\n"
"You have not provided enough information for us to be able to reproduce\n"
"the bug. Please provide a detailed account of the steps required to\n"
@@ -156,15 +156,15 @@ void KBBPrefs::setMessageButtonsDefault()
"able to reproduce, identify and fix the bug.\n");
mMessageButtons.insert(i18n("No Longer Applicable"),"Thank you for your bug report.\n"
"The bug that your reported no longer applies to the latest development\n"
- "(CVS) version of KDE. This is most probably because it has been fixed,\n"
+ "version of TDE. This is most probably because it has been fixed,\n"
"the application has been substantially modified or the application no\n"
"longer exists. The bug report will be closed.\n");
mMessageButtons.insert(i18n("Won't Fix Bug"),"Thank you for your bug report/feature request.\n"
"Unfortunately, this bug will never be fixed or the feature never\n"
"implemented. The bug report/feature request will be closed.\n");
mMessageButtons.insert(i18n("Cannot Reproduce Bug"),"Thank you for your bug report.\n"
- "This bug can not be reproduced using the current development (CVS)\n"
- "version of KDE. This suggests that the bug has already been fixed.\n"
+ "This bug can not be reproduced using the current development (GIT)\n"
+ "version of TDE. This suggests that the bug has already been fixed.\n"
"The bug report will be closed.\n");
}
diff --git a/kbugbuster/backend/mailsender.cpp b/kbugbuster/backend/mailsender.cpp
index 93b74eff..c4d4f9a1 100644
--- a/kbugbuster/backend/mailsender.cpp
+++ b/kbugbuster/backend/mailsender.cpp
@@ -107,7 +107,7 @@ bool MailSender::send(const TQString &fromName,const TQString &fromEmail,const T
return false;
}
- emit status( i18n( "Passing mail to KDE email program..." ) );
+ emit status( i18n( "Passing mail to TDE email program..." ) );
if (!kMailOpenComposer(to,"", (bcc ? from : ""), subject,body,0,KURL())) {
TQTimer::singleShot( 0, this, TQT_SLOT( deleteLater() ) );
return false;
diff --git a/kbugbuster/backend/bugserver.cpp b/kbugbuster/backend/bugserver.cpp
index 6c8aa6fb..1ad90567 100644
--- a/kbugbuster/backend/bugserver.cpp
+++ b/kbugbuster/backend/bugserver.cpp
@@ -54,7 +54,8 @@ void BugServer::init()
TQString bugzilla = mServerConfig.bugzillaVersion();
- if ( bugzilla == "KDE" ) mProcessor = new DomProcessor( this );
+ if ( bugzilla == "TDE" ) mProcessor = new DomProcessor( this );
+ else if ( bugzilla == "KDE" ) mProcessor = new DomProcessor( this );
else if ( bugzilla == "2.10" ) mProcessor = new HtmlParser_2_10( this );
else if ( bugzilla == "2.14.2" ) mProcessor = new HtmlParser_2_14_2( this );
else if ( bugzilla == "2.17.1" ) mProcessor = new HtmlParser_2_17_1( this );
@@ -231,8 +232,8 @@ void BugServer::sendCommands( MailSender *mailer, const TQString &senderName,
const TQString &senderEmail, bool sendBCC,
const TQString &recipient )
{
- // Disable mail commands for non-KDE servers
- if ( mServerConfig.baseUrl() != KURL( "http://bugs.kde.org" ) ) return;
+ // Disable mail commands for non-TDE servers
+ if ( mServerConfig.baseUrl() != KURL( "http://bugs.trinitydesktop.org" ) ) return;
TQString controlText;
@@ -249,7 +250,7 @@ void BugServer::sendCommands( MailSender *mailer, const TQString &senderName,
if (!cmd->package().isNull())
pkg = cmd->package();
if (!cmd->controlString().isNull()) {
- kdDebug() << "control@bugs.kde.org: " << cmd->controlString() << endl;
+ kdDebug() << "control@bugs.trinitydesktop.org: " << cmd->controlString() << endl;
controlText += cmd->controlString() + "\n";
} else {
kdDebug() << cmd->mailAddress() << ": " << cmd->mailText() << endl;
@@ -283,9 +284,9 @@ void BugServer::sendCommands( MailSender *mailer, const TQString &senderName,
}
if (!controlText.isEmpty()) {
- kdDebug() << "control@bugs.kde.org doesn't work anymore" << endl;
+ kdDebug() << "control@bugs.trinitydesktop.org doesn't work anymore" << endl;
#if 0
- if ( !mailer->send( senderName, senderEmail, "control@bugs.kde.org",
+ if ( !mailer->send( senderName, senderEmail, "control@bugs.trinitydesktop.org",
i18n("Mail generated by KBugBuster"), controlText,
sendBCC, recipient ))
return;